//		Extension to Barrier Shaper Block that deals with the ADC
//		tconv is typ. 3us
//		tacq is typ. 1.1 us
//		throughput of 200ksps is guaranteed
//		Follow timing diagram of Figure 7 from the datasheet
//		http://www.physics.utoronto.ca/~astummer/mirror/Projects/Barrier%20Shaper/Docs/LTC1867%20LinTech,%2012-16-bit%20ADC%20octal.pdf

//		Scheme for the ADC is to have a separate module that cycles through an input cycle for each 
//		of the eight ports of the ADC chip, and sends them back to the main module as eight busses
//		The main module sends this guy an 8-bit word to enable or disable the different ports
//		For now, the configuration words for each port are held in the body of this module

module BS2 (Port1, Port2, Port3, Port4, Port5, Port6, Port7, Port8,
			ADCsClk, ADCsSDI, ADCsSDO, ADCsCS, BS2Clk, Trigger, ports, Mode);

	input  				BS2Clk;										//  Clock
//	input  [7:0] ports;									//  Series of Bits to dictate which ports to read
	output reg 	[15:0]	Port1,Port2,Port3,Port4,Port5,Port6,Port7,Port8;  // Assuming the 16-bit ADC
	output reg			ADCsSDI,ADCsCS;							//  Slow ADC stuff
	output reg			ADCsClk;								//  Slow ADC stuff
	input				Trigger;								//	For triggered acquisitions
	input 				ADCsSDO;								//  Slow ADC stuff
	input		[7:0]	ports;									//	Inputs which ports to read - variable contains 8 bits, one for each port (read =1, don't read = 0), if trigger bit is set high, variable contains a value of which port to read
	input				Mode;									//	Choose triggered or continuous acquistions
	reg 		[2:0] 	CurrentPort;							//  Variable to keep track of which port to mash
	reg 		[11:0] 	Ct;										//  Counter to do timing
	reg 				UpdateCt;
	reg 		[3:0] 	i;										//  For the for loop
	reg 		[6:0]	Port1Config = 7'b0000001;					//  Configuration for different ports (see datasheet table 1)
	reg 		[6:0] 	Port2Config = 7'b0000011;					//  These are set up for single ended inputs for each channel
	reg 		[6:0] 	Port3Config = 7'b0001001;					//     from the port to ground, not common (controlled by 5th bit)
	reg 		[6:0] 	Port4Config = 7'b0001011;					//  sixth bit - unipolar
	reg 		[6:0] 	Port5Config = 7'b0000101;					//  seventh bit - sleep (1 = sleepy)   (MSB)
	reg 		[6:0] 	Port6Config = 7'b0000111;
	reg 		[6:0] 	Port7Config = 7'b0001101;
	reg 		[6:0] 	Port8Config = 7'b0001111;
//	reg 		[7:0] 	ports = 8'b11111111;					//  Series of Bits to dictate which ports to read

	always @ (negedge BS2Clk)  begin
//			ports = 8'b11111111;
/*			Port1Config = 7'b0000001;
			Port2Config = 7'b0000011;
			Port3Config = 7'b0001001;
			Port4Config = 7'b0001011;
			Port5Config = 7'b0000101;
			Port6Config = 7'b0000111;
			Port7Config = 7'b0001101;
			Port8Config = 7'b0001111;*/
			Port8Config = 7'b0000001;	//  Looks like I goofed these up a bit
			Port2Config = 7'b0000011;
			Port3Config = 7'b0001001;
			Port4Config = 7'b0001011;
			Port5Config = 7'b0000101;
			Port6Config = 7'b0000111;
			Port7Config = 7'b0001101;
			Port1Config = 7'b0001111;
			case (Mode)
				1'b0: 	begin
						if (Ct > 12'd400) begin  //  400 counts is the arbitrary limit for each read/write cycle... should probably be close to 320 or something
							Ct = 12'd0;			
							CurrentPort =CurrentPort + 3'b001;							
								for (i = 0; i < 9; i = i + 1) begin 										// Clumsy way of finding the next port to scan - at least it won't 
									if (ports[CurrentPort] == 1'b0) CurrentPort=CurrentPort + 3'b001;  	//hang if no ports are selected, but I'm not sure it would have anyway
								end
							end
						end
				1'b1: 	begin
							if ((Ct > 12'd400) && (Trigger == 1'b1)) begin
								Ct = 12'd0;
								CurrentPort = ports;
							end
						end
			endcase
//			end
			case (CurrentPort)
				0: begin		//  Right now I've only written this for 2 ports since I'm not sure about the timing
					case (Ct)	//	And they'll be pretty repetitive anyway
						12'd1: 		ADCsCS=1'b1;
						12'd2: 		ADCsCS=1'b0;
						12'd309:    begin ADCsSDI=Port1Config[0]; /*Port1[15] = ADCsSDO;*/ADCsClk=1'b0; end // Not so sure about the timing of this - probably need to test it with the hardware
						12'd310:	ADCsClk=1'b1;
						12'd311:	begin ADCsSDI=Port1Config[1]; /*Port1[14] = ADCsSDO;*/ ADCsClk=1'b0;end
						12'd312:	ADCsClk=1'b1;
						12'd313:	begin ADCsSDI=Port1Config[2]; Port1[15] = ADCsSDO; ADCsClk=1'b0;end
						12'd314:	ADCsClk=1'b1;
						12'd315:	begin ADCsSDI=Port1Config[3]; Port1[14] = ADCsSDO; ADCsClk=1'b0;end
						12'd316:	ADCsClk=1'b1;
						12'd317:	begin ADCsSDI=Port1Config[4]; Port1[13] = ADCsSDO; ADCsClk=1'b0;end
						12'd318:	ADCsClk=1'b1;
						12'd319:	begin ADCsSDI=Port1Config[5]; Port1[12] = ADCsSDO; ADCsClk=1'b0;end
						12'd320:	ADCsClk=1'b1;
						12'd321:	begin ADCsSDI=Port1Config[6]; Port1[11] = ADCsSDO; ADCsClk=1'b0;end
						12'd322:	ADCsClk=1'b1;
						12'd323:	begin Port1[10]=ADCsSDO; ADCsClk=1'b0; end
						12'd324:	ADCsClk=1'b1;
						12'd325:	begin Port1[9]=ADCsSDO; ADCsClk=1'b0; end
						12'd326:	ADCsClk=1'b1;
						12'd327:	begin Port1[8]=ADCsSDO; ADCsClk=1'b0; end
						12'd328:	ADCsClk=1'b1;
						12'd329:	begin Port1[7]=ADCsSDO; ADCsClk=1'b0; end
						12'd330:	ADCsClk=1'b1;
						12'd331:	begin Port1[6]=ADCsSDO; ADCsClk=1'b0; end
						12'd332:	ADCsClk=1'b1;
						12'd333:	begin Port1[5]=ADCsSDO; ADCsClk=1'b0; end
						12'd334:	ADCsClk=1'b1;
						12'd335:	begin Port1[4]=ADCsSDO; ADCsClk=1'b0; end
						12'd336:	ADCsClk=1'b1;
						12'd337:	begin Port1[3]=ADCsSDO; ADCsClk=1'b0; end
						12'd338:	ADCsClk=1'b1;
						12'd339:	begin Port1[2]=ADCsSDO; ADCsClk=1'b0; end
						12'd340:	ADCsClk=1'b1;
						12'd341:	begin Port1[1]=ADCsSDO; ADCsClk=1'b0; end
						12'd342:	ADCsClk=1'b1;
						12'd343:	begin Port1[0]=ADCsSDO; ADCsClk=1'b0; end
						12'd344:	ADCsClk=1'b1;
						12'd345:	ADCsClk=1'b1;
//						12'd344:	Port1 = 16'd0;					
					endcase
				   end
				1: begin		//  Right now I've only written this for 2 ports since I'm not sure about the timing
					case (Ct)	//	And they'll be pretty repetitive anyway
						12'd1: 		ADCsCS=1'b1;
						12'd2: 		ADCsCS=1'b0;
						12'd309:    begin ADCsSDI=Port2Config[0]; Port2[15]=ADCsSDO; ADCsClk=1'b0; end // Not so sure about the timing of this - probably need to test it with the hardware
						12'd310:	ADCsClk=1'b1;
						12'd311:	begin ADCsSDI=Port2Config[1]; Port2[14]=ADCsSDO; ADCsClk=1'b0;end
						12'd312:	ADCsClk=1'b1;
						12'd313:	begin ADCsSDI=Port2Config[2]; Port2[13]=ADCsSDO; ADCsClk=1'b0;end
						12'd314:	ADCsClk=1'b1;
						12'd315:	begin ADCsSDI=Port2Config[3]; Port2[12]=ADCsSDO; ADCsClk=1'b0;end
						12'd316:	ADCsClk=1'b1;
						12'd317:	begin ADCsSDI=Port2Config[4]; Port2[11]=ADCsSDO; ADCsClk=1'b0;end
						12'd318:	ADCsClk=1'b1;
						12'd319:	begin ADCsSDI=Port2Config[5]; Port2[10]=ADCsSDO; ADCsClk=1'b0;end
						12'd320:	ADCsClk=1'b1;
						12'd321:	begin ADCsSDI=Port2Config[6]; Port2[9]=ADCsSDO; ADCsClk=1'b0;end
						12'd322:	ADCsClk=1'b1;
						12'd323:	begin Port2[8]=ADCsSDO; ADCsClk=1'b0; end
						12'd324:	ADCsClk=1'b1;
						12'd325:	begin Port2[7]=ADCsSDO; ADCsClk=1'b0; end
						12'd326:	ADCsClk=1'b1;
						12'd327:	begin Port2[6]=ADCsSDO; ADCsClk=1'b0; end
						12'd328:	ADCsClk=1'b1;
						12'd329:	begin Port2[5]=ADCsSDO; ADCsClk=1'b0; end
						12'd330:	ADCsClk=1'b1;
						12'd331:	begin Port2[4]=ADCsSDO; ADCsClk=1'b0; end
						12'd332:	ADCsClk=1'b1;
						12'd333:	begin Port2[3]=ADCsSDO; ADCsClk=1'b0; end
						12'd334:	ADCsClk=1'b1;
						12'd335:	begin Port2[2]=ADCsSDO; ADCsClk=1'b0; end
						12'd336:	ADCsClk=1'b1;
						12'd337:	begin Port2[1]=ADCsSDO; ADCsClk=1'b0; end
						12'd338:	ADCsClk=1'b1;
						12'd339:	begin Port2[0]=ADCsSDO; ADCsClk=1'b0; end
						12'd340:	ADCsClk=1'b1;
						12'd341:	begin /*Port2[0]=ADCsSDO;*/ ADCsClk=1'b0; end
						12'd342:	ADCsClk=1'b1;
						12'd343:	ADCsClk=1'b1;					
					endcase
				   end
				2: begin		//  Right now I've only written this for 2 ports since I'm not sure about the timing
					case (Ct)	//	And they'll be pretty repetitive anyway
						12'd1: 		ADCsCS=1'b1;
						12'd2: 		ADCsCS=1'b0;
						12'd309:    begin ADCsSDI=Port3Config[0]; ADCsClk=1'b0; end // Not so sure about the timing of this - probably need to test it with the hardware
						12'd310:	ADCsClk=1'b1;
						12'd311:	begin ADCsSDI=Port3Config[1]; Port3[15]=ADCsSDO; ADCsClk=1'b0;end
						12'd312:	ADCsClk=1'b1;
						12'd313:	begin ADCsSDI=Port3Config[2]; Port3[14]=ADCsSDO; ADCsClk=1'b0;end
						12'd314:	ADCsClk=1'b1;
						12'd315:	begin ADCsSDI=Port3Config[3]; Port3[13]=ADCsSDO; ADCsClk=1'b0;end
						12'd316:	ADCsClk=1'b1;
						12'd317:	begin ADCsSDI=Port3Config[4]; Port3[12]=ADCsSDO; ADCsClk=1'b0;end
						12'd318:	ADCsClk=1'b1;
						12'd319:	begin ADCsSDI=Port3Config[5]; Port3[11]=ADCsSDO; ADCsClk=1'b0;end
						12'd320:	ADCsClk=1'b1;
						12'd321:	begin ADCsSDI=Port3Config[6]; Port3[10]=ADCsSDO; ADCsClk=1'b0;end
						12'd322:	ADCsClk=1'b1;
						12'd323:	begin Port3[9]=ADCsSDO; ADCsClk=1'b0; end
						12'd324:	ADCsClk=1'b1;
						12'd325:	begin Port3[8]=ADCsSDO; ADCsClk=1'b0; end
						12'd326:	ADCsClk=1'b1;
						12'd327:	begin Port3[7]=ADCsSDO; ADCsClk=1'b0; end
						12'd328:	ADCsClk=1'b1;
						12'd329:	begin Port3[6]=ADCsSDO; ADCsClk=1'b0; end
						12'd330:	ADCsClk=1'b1;
						12'd331:	begin Port3[5]=ADCsSDO; ADCsClk=1'b0; end
						12'd332:	ADCsClk=1'b1;
						12'd333:	begin Port3[4]=ADCsSDO; ADCsClk=1'b0; end
						12'd334:	ADCsClk=1'b1;
						12'd335:	begin Port3[3]=ADCsSDO; ADCsClk=1'b0; end
						12'd336:	ADCsClk=1'b1;
						12'd337:	begin Port3[2]=ADCsSDO; ADCsClk=1'b0; end
						12'd338:	ADCsClk=1'b1;
						12'd339:	begin Port3[1]=ADCsSDO; ADCsClk=1'b0; end
						12'd340:	ADCsClk=1'b1;
						12'd341:	begin Port3[0]=ADCsSDO; ADCsClk=1'b0; end
						12'd342:	ADCsClk=1'b1;
						12'd343:	ADCsClk=1'b1;					
					endcase
				   end
				3: begin		//  Right now I've only written this for 2 ports since I'm not sure about the timing
					case (Ct)	//	And they'll be pretty repetitive anyway
						12'd1: 		ADCsCS=1'b1;
						12'd2: 		ADCsCS=1'b0;
						12'd309:    begin ADCsSDI=Port4Config[0]; ADCsClk=1'b0; end // Not so sure about the timing of this - probably need to test it with the hardware
						12'd310:	ADCsClk=1'b1;
						12'd311:	begin ADCsSDI=Port4Config[1]; Port4[15]=ADCsSDO; ADCsClk=1'b0;end
						12'd312:	ADCsClk=1'b1;
						12'd313:	begin ADCsSDI=Port4Config[2]; Port4[14]=ADCsSDO; ADCsClk=1'b0;end
						12'd314:	ADCsClk=1'b1;
						12'd315:	begin ADCsSDI=Port4Config[3]; Port4[13]=ADCsSDO; ADCsClk=1'b0;end
						12'd316:	ADCsClk=1'b1;
						12'd317:	begin ADCsSDI=Port4Config[4]; Port4[12]=ADCsSDO; ADCsClk=1'b0;end
						12'd318:	ADCsClk=1'b1;
						12'd319:	begin ADCsSDI=Port4Config[5]; Port4[11]=ADCsSDO; ADCsClk=1'b0;end
						12'd320:	ADCsClk=1'b1;
						12'd321:	begin ADCsSDI=Port4Config[6]; Port4[10]=ADCsSDO; ADCsClk=1'b0;end
						12'd322:	ADCsClk=1'b1;
						12'd323:	begin Port4[9]=ADCsSDO; ADCsClk=1'b0; end
						12'd324:	ADCsClk=1'b1;
						12'd325:	begin Port4[8]=ADCsSDO; ADCsClk=1'b0; end
						12'd326:	ADCsClk=1'b1;
						12'd327:	begin Port4[7]=ADCsSDO; ADCsClk=1'b0; end
						12'd328:	ADCsClk=1'b1;
						12'd329:	begin Port4[6]=ADCsSDO; ADCsClk=1'b0; end
						12'd330:	ADCsClk=1'b1;
						12'd331:	begin Port4[5]=ADCsSDO; ADCsClk=1'b0; end
						12'd332:	ADCsClk=1'b1;
						12'd333:	begin Port4[4]=ADCsSDO; ADCsClk=1'b0; end
						12'd334:	ADCsClk=1'b1;
						12'd335:	begin Port4[3]=ADCsSDO; ADCsClk=1'b0; end
						12'd336:	ADCsClk=1'b1;
						12'd337:	begin Port4[2]=ADCsSDO; ADCsClk=1'b0; end
						12'd338:	ADCsClk=1'b1;
						12'd339:	begin Port4[1]=ADCsSDO; ADCsClk=1'b0; end
						12'd340:	ADCsClk=1'b1;
						12'd341:	begin Port4[0]=ADCsSDO; ADCsClk=1'b0; end
						12'd342:	ADCsClk=1'b1;
						12'd343:	ADCsClk=1'b1;					
					endcase
				   end
				4: begin		//  Right now I've only written this for 2 ports since I'm not sure about the timing
					case (Ct)	//	And they'll be pretty repetitive anyway
						12'd1: 		ADCsCS=1'b1;
						12'd2: 		ADCsCS=1'b0;
						12'd309:    begin ADCsSDI=Port5Config[0]; ADCsClk=1'b0; end // Not so sure about the timing of this - probably need to test it with the hardware
						12'd310:	ADCsClk=1'b1;
						12'd311:	begin ADCsSDI=Port5Config[1]; Port5[15]=ADCsSDO; ADCsClk=1'b0;end
						12'd312:	ADCsClk=1'b1;
						12'd313:	begin ADCsSDI=Port5Config[2]; Port5[14]=ADCsSDO; ADCsClk=1'b0;end
						12'd314:	ADCsClk=1'b1;
						12'd315:	begin ADCsSDI=Port5Config[3]; Port5[13]=ADCsSDO; ADCsClk=1'b0;end
						12'd316:	ADCsClk=1'b1;
						12'd317:	begin ADCsSDI=Port5Config[4]; Port5[12]=ADCsSDO; ADCsClk=1'b0;end
						12'd318:	ADCsClk=1'b1;
						12'd319:	begin ADCsSDI=Port5Config[5]; Port5[11]=ADCsSDO; ADCsClk=1'b0;end
						12'd320:	ADCsClk=1'b1;
						12'd321:	begin ADCsSDI=Port5Config[6]; Port5[10]=ADCsSDO; ADCsClk=1'b0;end
						12'd322:	ADCsClk=1'b1;
						12'd323:	begin Port5[9]=ADCsSDO; ADCsClk=1'b0; end
						12'd324:	ADCsClk=1'b1;
						12'd325:	begin Port5[8]=ADCsSDO; ADCsClk=1'b0; end
						12'd326:	ADCsClk=1'b1;
						12'd327:	begin Port5[7]=ADCsSDO; ADCsClk=1'b0; end
						12'd328:	ADCsClk=1'b1;
						12'd329:	begin Port5[6]=ADCsSDO; ADCsClk=1'b0; end
						12'd330:	ADCsClk=1'b1;
						12'd331:	begin Port5[5]=ADCsSDO; ADCsClk=1'b0; end
						12'd332:	ADCsClk=1'b1;
						12'd333:	begin Port5[4]=ADCsSDO; ADCsClk=1'b0; end
						12'd334:	ADCsClk=1'b1;
						12'd335:	begin Port5[3]=ADCsSDO; ADCsClk=1'b0; end
						12'd336:	ADCsClk=1'b1;
						12'd337:	begin Port5[2]=ADCsSDO; ADCsClk=1'b0; end
						12'd338:	ADCsClk=1'b1;
						12'd339:	begin Port5[1]=ADCsSDO; ADCsClk=1'b0; end
						12'd340:	ADCsClk=1'b1;
						12'd341:	begin Port5[0]=ADCsSDO; ADCsClk=1'b0; end
						12'd342:	ADCsClk=1'b1;
						12'd343:	ADCsClk=1'b1;					
					endcase
				   end
				5: begin		//  Right now I've only written this for 2 ports since I'm not sure about the timing
					case (Ct)	//	And they'll be pretty repetitive anyway
						12'd1: 		ADCsCS=1'b1;
						12'd2: 		ADCsCS=1'b0;
						12'd309:    begin ADCsSDI=Port6Config[0]; ADCsClk=1'b0; end // Not so sure about the timing of this - probably need to test it with the hardware
						12'd310:	ADCsClk=1'b1;
						12'd311:	begin ADCsSDI=Port6Config[1]; Port6[15]=ADCsSDO; ADCsClk=1'b0;end
						12'd312:	ADCsClk=1'b1;
						12'd313:	begin ADCsSDI=Port6Config[2]; Port6[14]=ADCsSDO; ADCsClk=1'b0;end
						12'd314:	ADCsClk=1'b1;
						12'd315:	begin ADCsSDI=Port6Config[3]; Port6[13]=ADCsSDO; ADCsClk=1'b0;end
						12'd316:	ADCsClk=1'b1;
						12'd317:	begin ADCsSDI=Port6Config[4]; Port6[12]=ADCsSDO; ADCsClk=1'b0;end
						12'd318:	ADCsClk=1'b1;
						12'd319:	begin ADCsSDI=Port6Config[5]; Port6[11]=ADCsSDO; ADCsClk=1'b0;end
						12'd320:	ADCsClk=1'b1;
						12'd321:	begin ADCsSDI=Port6Config[6]; Port6[10]=ADCsSDO; ADCsClk=1'b0;end
						12'd322:	ADCsClk=1'b1;
						12'd323:	begin Port6[9]=ADCsSDO; ADCsClk=1'b0; end
						12'd324:	ADCsClk=1'b1;
						12'd325:	begin Port6[8]=ADCsSDO; ADCsClk=1'b0; end
						12'd326:	ADCsClk=1'b1;
						12'd327:	begin Port6[7]=ADCsSDO; ADCsClk=1'b0; end
						12'd328:	ADCsClk=1'b1;
						12'd329:	begin Port6[6]=ADCsSDO; ADCsClk=1'b0; end
						12'd330:	ADCsClk=1'b1;
						12'd331:	begin Port6[5]=ADCsSDO; ADCsClk=1'b0; end
						12'd332:	ADCsClk=1'b1;
						12'd333:	begin Port6[4]=ADCsSDO; ADCsClk=1'b0; end
						12'd334:	ADCsClk=1'b1;
						12'd335:	begin Port6[3]=ADCsSDO; ADCsClk=1'b0; end
						12'd336:	ADCsClk=1'b1;
						12'd337:	begin Port6[2]=ADCsSDO; ADCsClk=1'b0; end
						12'd338:	ADCsClk=1'b1;
						12'd339:	begin Port6[1]=ADCsSDO; ADCsClk=1'b0; end
						12'd340:	ADCsClk=1'b1;
						12'd341:	begin Port6[0]=ADCsSDO; ADCsClk=1'b0; end
						12'd342:	ADCsClk=1'b1;
						12'd343:	ADCsClk=1'b1;					
					endcase
				   end
				6: begin		//  Right now I've only written this for 2 ports since I'm not sure about the timing
					case (Ct)	//	And they'll be pretty repetitive anyway
						12'd1: 		ADCsCS=1'b1;
						12'd2: 		ADCsCS=1'b0;
						12'd309:    begin ADCsSDI=Port7Config[0]; ADCsClk=1'b0; end // Not so sure about the timing of this - probably need to test it with the hardware
						12'd310:	ADCsClk=1'b1;
						12'd311:	begin ADCsSDI=Port7Config[1]; Port7[15]=ADCsSDO; ADCsClk=1'b0;end
						12'd312:	ADCsClk=1'b1;
						12'd313:	begin ADCsSDI=Port7Config[2]; Port7[14]=ADCsSDO; ADCsClk=1'b0;end
						12'd314:	ADCsClk=1'b1;
						12'd315:	begin ADCsSDI=Port7Config[3]; Port7[13]=ADCsSDO; ADCsClk=1'b0;end
						12'd316:	ADCsClk=1'b1;
						12'd317:	begin ADCsSDI=Port7Config[4]; Port7[12]=ADCsSDO; ADCsClk=1'b0;end
						12'd318:	ADCsClk=1'b1;
						12'd319:	begin ADCsSDI=Port7Config[5]; Port7[11]=ADCsSDO; ADCsClk=1'b0;end
						12'd320:	ADCsClk=1'b1;
						12'd321:	begin ADCsSDI=Port7Config[6]; Port7[10]=ADCsSDO; ADCsClk=1'b0;end
						12'd322:	ADCsClk=1'b1;
						12'd323:	begin Port7[9]=ADCsSDO; ADCsClk=1'b0; end
						12'd324:	ADCsClk=1'b1;
						12'd325:	begin Port7[8]=ADCsSDO; ADCsClk=1'b0; end
						12'd326:	ADCsClk=1'b1;
						12'd327:	begin Port7[7]=ADCsSDO; ADCsClk=1'b0; end
						12'd328:	ADCsClk=1'b1;
						12'd329:	begin Port7[6]=ADCsSDO; ADCsClk=1'b0; end
						12'd330:	ADCsClk=1'b1;
						12'd331:	begin Port7[5]=ADCsSDO; ADCsClk=1'b0; end
						12'd332:	ADCsClk=1'b1;
						12'd333:	begin Port7[4]=ADCsSDO; ADCsClk=1'b0; end
						12'd334:	ADCsClk=1'b1;
						12'd335:	begin Port7[3]=ADCsSDO; ADCsClk=1'b0; end
						12'd336:	ADCsClk=1'b1;
						12'd337:	begin Port7[2]=ADCsSDO; ADCsClk=1'b0; end
						12'd338:	ADCsClk=1'b1;
						12'd339:	begin Port7[1]=ADCsSDO; ADCsClk=1'b0; end
						12'd340:	ADCsClk=1'b1;
						12'd341:	begin Port7[0]=ADCsSDO; ADCsClk=1'b0; end
						12'd342:	ADCsClk=1'b1;
						12'd343:	ADCsClk=1'b1;					
					endcase
				   end
				7: begin		//  Right now I've only written this for 2 ports since I'm not sure about the timing
					case (Ct)	//	And they'll be pretty repetitive anyway
						12'd1: 		ADCsCS=1'b1;
						12'd2: 		ADCsCS=1'b0;
						12'd309:    begin ADCsSDI=Port8Config[0]; ADCsClk=1'b0; end // Not so sure about the timing of this - probably need to test it with the hardware
						12'd310:	ADCsClk=1'b1;
						12'd311:	begin ADCsSDI=Port8Config[1]; Port8[15]=ADCsSDO; ADCsClk=1'b0;end
						12'd312:	ADCsClk=1'b1;
						12'd313:	begin ADCsSDI=Port8Config[2]; Port8[14]=ADCsSDO; ADCsClk=1'b0;end
						12'd314:	ADCsClk=1'b1;
						12'd315:	begin ADCsSDI=Port8Config[3]; Port8[13]=ADCsSDO; ADCsClk=1'b0;end
						12'd316:	ADCsClk=1'b1;
						12'd317:	begin ADCsSDI=Port8Config[4]; Port8[12]=ADCsSDO; ADCsClk=1'b0;end
						12'd318:	ADCsClk=1'b1;
						12'd319:	begin ADCsSDI=Port8Config[5]; Port8[11]=ADCsSDO; ADCsClk=1'b0;end
						12'd320:	ADCsClk=1'b1;
						12'd321:	begin ADCsSDI=Port8Config[6]; Port8[10]=ADCsSDO; ADCsClk=1'b0;end
						12'd322:	ADCsClk=1'b1;
						12'd323:	begin Port8[9]=ADCsSDO; ADCsClk=1'b0; end
						12'd324:	ADCsClk=1'b1;
						12'd325:	begin Port8[8]=ADCsSDO; ADCsClk=1'b0; end
						12'd326:	ADCsClk=1'b1;
						12'd327:	begin Port8[7]=ADCsSDO; ADCsClk=1'b0; end
						12'd328:	ADCsClk=1'b1;
						12'd329:	begin Port8[6]=ADCsSDO; ADCsClk=1'b0; end
						12'd330:	ADCsClk=1'b1;
						12'd331:	begin Port8[5]=ADCsSDO; ADCsClk=1'b0; end
						12'd332:	ADCsClk=1'b1;
						12'd333:	begin Port8[4]=ADCsSDO; ADCsClk=1'b0; end
						12'd334:	ADCsClk=1'b1;
						12'd335:	begin Port8[3]=ADCsSDO; ADCsClk=1'b0; end
						12'd336:	ADCsClk=1'b1;
						12'd337:	begin Port8[2]=ADCsSDO; ADCsClk=1'b0; end
						12'd338:	ADCsClk=1'b1;
						12'd339:	begin Port8[1]=ADCsSDO; ADCsClk=1'b0; end
						12'd340:	ADCsClk=1'b1;
						12'd341:	begin Port8[0]=ADCsSDO; ADCsClk=1'b0; end
						12'd342:	ADCsClk=1'b1;
						12'd343:	ADCsClk=1'b1;					
					endcase
				   end


			endcase
			if (Ct < 12'd500) Ct=Ct+12'b1;
		end
endmodule