/* Barrier Shaper.  Contact is Chris Ellenor for Aephraim.  Project started
	July 2005.  Hardware by Alan Stummer, most Verilog by Chris.

 Generated by Quartus II Version 5.0 (Build Build 148 04/26/2005)
 Created on Wed Jul 13 15:30:39 2005
*/

//  Module Declaration
module BSblock (Clk, DACf, USB,DACfClk,DACsClk, LUTadd, LUTdata,Dig,Port1,Port2,Port3,
					Port4,Port5,Port6,Port7,Port8,DACsTrigger,DACsAddress, 
					DACsCommand,DACsDataWord,LUTupdate,LUTwr,ADCClk,Sign, ADCPorts, ADCTrigger,
					ADCMode);

//	General Assigments

	input             	Clk;					   		//  the master 100MHz clock.
	output 				DACfClk;						//  Clock controlling the fast DAC
	inout		[15:0] 	USB;						 	//  bidirectional USB bus.
	output   	[11:0] 	DACf;							//  Fast single 12-bit DAC.
	assign  			Dig[0] = USB[15];
	assign  			Dig[1] = USB[14];
	assign  			Dig[2] = USB[13];

	output 		[7:0] 	Dig;						   	//  Digital Input
	assign				DACfClk	= Clk;					//	Use DACsClk <= !DACsClk on posedges to divide down
//	assign 				LUTupdate = LUTUpdateData;
	output 				DACsClk;						//  Clock controlling the slow DAC
	output reg  		DACsTrigger;
	output reg 	[3:0] 	DACsAddress, DACsCommand;		//  Outputs to Slow DACs
	output		[15:0]  DACsDataWord;
	reg			[15:0]	DACsDWHolder;
	reg			[8:0]	DACsAddHolder;
	assign				DACsClk	= Clk;					//  Clock for slow DACs... datasheet specifies 50 MHz max clock, but 100 MHz seems to work just fine
	input 		[15:0] 	Port1,Port2,Port3,Port4,Port5,Port6,Port7,Port8;  //  Input from Slow ADCs
	output reg	[11:0] 	LUTupdate;						//  LUT input data
	output      [10:0] 	LUTadd;							//  LUT address bus.
	output reg			LUTwr;							//  LUT wr control
	output reg			ADCClk;							//  Clock controlling the ADCs - Max on datasheet is 40MHz
	input       [11:0] 	LUTdata;					  	//  LUT data bus, input.
	output				Sign;
	output reg	[7:0]	ADCPorts;
	output reg			ADCTrigger;
	output reg			ADCMode;
	reg 		[31:0]	Ptr;							//	Used as address holder for LUT
	reg 		[7:0]	DataOut;						//	Register for data on its way out the USB
	reg			[11:0]	DACSingleOut;
	reg			[11:0]	LUTUpdateData;
	reg			[4:0]	DACfLimit;
	reg			[15:0]	Setpoint;
	reg			[15:0]	FeedbackDACOutput;
	reg			[15:0]	AOMAMUpperLimit;
	reg			[15:0]	AOMAMLowerLimit;
	wire		[15:0]	Feedback;
	reg			[7:0]	FBCtr;							//	Counter to regulate time constant of feedback loop
	reg			[15:0]	FeedbackStep;
	reg			[7:0]	tc;								//	Time Constant variable - 

	assign  DACf[11:0] = ((USB[15:12] == 4'b1011)||(USB[15:12] == 4'b1110)||(USB[15:12] == 4'b1100)) ? LUTdata[11:0] : DACSingleOut;	 // pipe the LUT directly to the fast DAC
 	assign  LUTadd = (USB[15:12] == 4'b1100) ? Ptr[28:17] : Ptr[10:0];		 				// Ptr is the address of the lookup table to output
	assign 	USB[7:0] = (USB[15:12] == 4'b0100) ? DataOut : 8'bz;
	assign	DACsDataWord = (USB[15:12] == 4'b1110) ? FeedbackDACOutput : DACsDWHolder;
	assign	Feedback = (Setpoint - Port1) + 16'd32768;

	always @ (posedge Clk)  begin
		ADCClk = !ADCClk;
		AOMAMUpperLimit = 16'd2302+16'd32768;		//  Should Correspond to 0.4 V - Knob should always be set 'twixt zero and 0.2 V!!
		AOMAMLowerLimit = 16'd32768;				//	Can be zero volts
		/** Testing Fun USB Stuff **/
		//   Control word is USB[15:8], DataOut is USB[7:0]
		/*	 Control word for now breaks down as:
				15:12		0000
							0001			->	Output to fast DAC idler
							0010			->  Ouput to slow DAC
							0011
							0100			->	Output ADC States
							0101			->	Output Single Value to fast DAC
							0110
							0111			->	Upload Waveform (Address Get)
							1000
							1001
							1010			->	Output single value to fast DAC (use calibration)
							1011			->	Just outputting data from LUT
							1100			->	1011 but slow
							1101			->	Upload Waveform (Data Get)
							1110			->	1011 with feedback loop 
							1111			->	Upload Waveform (Address Idle, Data Idle)
*/
							
		case (USB[15:12])
			4'b1100: 	begin									//  Default State which outputs the fast DC business
							LUTwr = 1'b0;						//	Slow Version
							Ptr = Ptr + 32'd1;
							if (Ptr[28:17] > 12'd999)  Ptr = 32'd0;
						end
			4'b1011: 	begin									//  Default State which outputs the fast DC business
							LUTwr = 1'b0;						
							Ptr = Ptr + 32'd1;
							if (Ptr[10:0] > 32'd999)  Ptr = 32'd0;
						end
			4'b1110: 	begin									//  Default State which outputs the fast DC business
							ADCMode = 1'b1;
							ADCPorts = 0;						//	Feedback from port zero
							LUTwr = 1'b0;						//	Version with feedback loop for power
							Ptr = Ptr + 32'd1;
							if (Ptr[10:0] > 32'd999)	begin
													  		Ptr = 32'd0;
															ADCTrigger = 1'b1;		//  Initiate Data Acquision - this needs to be timed
														end
/*							if (Ptr[10:0] == 32'd100)
								begin
									HugeCtr = HugeCtr + 32'b1;
									if ((Feedback > 16'd32768) && (Feedback < 16'd65535))
										begin
											if ((FeedbackDACOutput - FeedbackStep) > AOMAMLowerLimit) FeedbackDACOutput = FeedbackDACOutput - FeedbackStep;
										end
									if ((Feedback < 16'd32769) && (Feedback > 16'd0))
										begin
											if ((FeedbackDACOutput + FeedbackStep) < AOMAMUpperLimit) FeedbackDACOutput = FeedbackDACOutput + FeedbackStep;
										end
//									FeedbackDACOutput = Feedback;
								end						*/
							if (Ptr[10:0] == 32'd500)
								begin
									FBCtr = FBCtr + 12'b1;
									if ((Feedback > 16'd32768) && (Feedback < 16'd65535) && ((FBCtr % tc) == 8'b0))
										begin
											if ((FeedbackDACOutput - FeedbackStep) > AOMAMLowerLimit) FeedbackDACOutput = FeedbackDACOutput - FeedbackStep;
										end
									if ((Feedback < 16'd32769) && (Feedback > 16'd0) && ((FBCtr % tc) == 8'b0))
										begin
											if ((FeedbackDACOutput + FeedbackStep) < AOMAMUpperLimit) FeedbackDACOutput = FeedbackDACOutput + FeedbackStep;
										end
//									FeedbackDACOutput = Feedback;
								end						
							DACsAddress = 4'b0;
							if (USB[11] == 1'b1) FeedbackDACOutput = Port1;
							if (Ptr[10:0] == 32'd800)
								begin
									DACsTrigger = 1'b1;
								end
							if (Ptr[10:0] == 32'd810)
								begin
									DACsTrigger = 1'b0;
								end
							if (Ptr[10:0] == 32'd5)	ADCTrigger = 1'b0;
						end
			4'b1001:	begin					//  Upload Parameters for Feedback Loop
							case (USB[11:8])	//  Trying to use a Gray code here for sequential input... not sure it's useful in this particular case
								4'b0001:	Setpoint[15:8] 		= USB[7:0];
								4'b0011:	Setpoint[7:0] 		= USB[7:0];
								4'b0010:	FeedbackStep[15:8] 	= USB[7:0];
								4'b0110:	FeedbackStep[7:0]	= USB[7:0];
								4'b0100:	tc[7:0] 			= USB[7:0];
							endcase
						end
			4'b0010:	begin									//	Output to slow DAC
							DACsTrigger = 1'b1;
							DACsAddress = 4'b1111;
							DACsDWHolder = {USB[11:0],4'b0000};  // For now just write the first 12 bits as the rest of the USB, and the next four just zeroes
						end
	
/*  Memory Programming:

LabView Will produce 6 strings across the USB:
1)  Control 1111 with Address bit loaded
2)  Control 0111 with Address bit loaded
3)  Control 1111 with Address bit loaded
4)  Control 1111 with Data bit loaded
5)  Control 1101 with Data bit loaded
6)  Control 1111 with Data bit loaded  */
					
			4'b0111: 	begin									//  Program Memory:
							Ptr = USB[10:0];					//		Get next address to program to from USB
						end
			4'b1101: 	begin									//  Program Memory:
							LUTwr = 1'b1;						//		Get data to stick in memory
							LUTupdate = USB[11:0];
						end

			4'b0101:	begin						//  Output single value for fast DAC - used for calibration routine
							DACSingleOut <= USB[11:0];
						end
			4'b0100:	begin						//  Output ADC result					
							ADCTrigger = 1'b0;		//  Untriggered mode should leave this 
							ADCPorts = 8'b11111111;
							ADCMode = 1'b0;
							case (USB[8])
								1'b0: 	begin
											case (USB[11:9])
												3'b000:  		DataOut = Port1[7:0];
												3'b001:  		DataOut = Port2[7:0];
												3'b010:  		DataOut = Port3[7:0];
												3'b011:  		DataOut = Port4[7:0];
												3'b100:  		DataOut = Port5[7:0];
												3'b101:  		DataOut = Port6[7:0];
												3'b110:  		DataOut = Port7[7:0];
												3'b111:  		DataOut = Port8[7:0];
											endcase
										end							
								1'b1: 	begin
											case (USB[11:9])
												3'b000:  		DataOut = Port1[15:8];
												3'b001:  		DataOut = Port2[15:8];
												3'b010:  		DataOut = Port3[15:8];
												3'b011:  		DataOut = Port4[15:8];
												3'b100:  		DataOut = Port5[15:8];
												3'b101:  		DataOut = Port6[15:8];
												3'b110:  		DataOut = Port7[15:8];
												3'b111:  		DataOut = Port8[15:8];
											endcase
										end							
							endcase
						end
			default: 	begin DACsTrigger = 1'b0; LUTwr = 1'b0; end

		endcase
	end
endmodule
